@@ -80,7 +80,7 @@ class DiscreteEnv(gym.Env):
 #"action" argument is one value in the range of the action space (logit transform)
   def step(self, action):
     
-    self.df.sample(n=1, random_state=1).values.reshape(3,) = self.state
+    self.state = self.df.sample(n=1, random_state=1).values.reshape(3,)
     #compute rho
     Xsa=(self.thetas[0])+(self.thetas[1])*(self.state[0])+(self.thetas[2])*(self.state[1])
     rho1=0.2   
@@ -108,6 +108,12 @@ class DiscreteEnv(gym.Env):
     
     #depending on the value of self.state, apply a reward
     reward = self.Ynew_cumul 
+    
+    model_updated = LogisticRegression().fit(self.df[["Xs", "Xa"]], np.ravel(self.df[["Y"]]))
+
+    #extract theta parameters from the fitted logistic
+    theta_updated = np.array([self.model.coef_[0,1]]) #thetas[1] coef for Xs, thetas[2] coef for Xa
+
 
     #check if horion is over, otherwise keep on doing
     if self.horizon <= 0:
@@ -118,7 +124,7 @@ class DiscreteEnv(gym.Env):
     #set placeholder for infos
     info ={}        
      
-    return self.state, reward, done, {}
+    return self.state, reward, done, theta_updated , {}
 
 #reset state and horizon    
   def reset(self):
